pub enum ProtectionError {
CrossOriginRequest,
CrossOriginRequestFromOldBrowser,
MalformedHost(ParseError),
MalformedOrigin(ParseError),
}Expand description
Errors that can occur during request processing of the middleware.
These errors must be handled when using the middleware in web frameworks (such as axum) to e.g. log errors or render appropriate responses.
Variants
CrossOriginRequest
A cross-origin request was detected.
CrossOriginRequestFromOldBrowser
A cross-origin request was detected.
MalformedHost(ParseError)
The host request header cannot be parsed.
MalformedOrigin(ParseError)
The origin request header cannot be parsed.