pub struct CrossOriginProtectionLayer { /* private fields */ }Expand description
Decorates a HTTP service with CSRF protection.
Implementations
Sourceimpl CrossOriginProtectionLayer
impl CrossOriginProtectionLayer
Sourcepub fn add_trusted_origin<S: Into<String>>(
self,
origin: S,
) -> Result<Self, ConfigError>
pub fn add_trusted_origin<S: Into<String>>( self, origin: S, ) -> Result<Self, ConfigError>
Adds a trusted origin which allows all requests with an Origin header which exactly matches
the given value.
Origin header values are of the form scheme://host[:port].
Sourcepub fn with_insecure_bypass<F>(self, predicate: F) -> CrossOriginProtectionLayer
pub fn with_insecure_bypass<F>(self, predicate: F) -> CrossOriginProtectionLayer
Adds a bypass function that returns true if the given request should bypass CSRF protection. Notes that this
might be insecure.